var BoundingBoxD_8h =
[
    [ "BoundingBoxD", "classIMP_1_1algebra_1_1BoundingBoxD.html", "classIMP_1_1algebra_1_1BoundingBoxD" ],
    [ "BoundingBox1D", "BoundingBoxD_8h.html#a7eb3cac9d0dd97a605a803c3c1c9a7cb", null ],
    [ "BoundingBox1Ds", "BoundingBoxD_8h.html#aa2cc974f99659c4096caa442a6e9575c", null ],
    [ "BoundingBox2D", "BoundingBoxD_8h.html#a1b14e4914ad97543ce955f34f2e61752", null ],
    [ "BoundingBox2Ds", "BoundingBoxD_8h.html#af080b2296402ebd30e7f3d0649bbcb02", null ],
    [ "BoundingBox3D", "BoundingBoxD_8h.html#a185f2504357db1e9a24a03d26cec4079", null ],
    [ "BoundingBox3Ds", "BoundingBoxD_8h.html#a8d05f8947ac3445403fa4bfbc70cea0d", null ],
    [ "BoundingBox4D", "BoundingBoxD_8h.html#af9789e57e6fd60240be2f8bb4a9eabb6", null ],
    [ "BoundingBox4Ds", "BoundingBoxD_8h.html#aa74fe6a09026b0188d0fce92de90146a", null ],
    [ "BoundingBox5D", "BoundingBoxD_8h.html#a0ee9f049309eb6756f2ce1a6d7d4d3cf", null ],
    [ "BoundingBox5Ds", "BoundingBoxD_8h.html#a20ccc6c13f474647249a5bb20ae4d8b2", null ],
    [ "BoundingBox6D", "BoundingBoxD_8h.html#abe8e949accf9c66f00dde408e29794ff", null ],
    [ "BoundingBox6Ds", "BoundingBoxD_8h.html#ac5b318d1848a44117db30f65e6196d18", null ],
    [ "BoundingBoxKD", "BoundingBoxD_8h.html#a4882602f27f726c425028dc402de4562", null ],
    [ "BoundingBoxKDs", "BoundingBoxD_8h.html#ad077a80677a797fb8525bfde8bbd2f77", null ],
    [ "get_cube_d", "BoundingBoxD_8h.html#afc7bf8d6b520c4abfed644b0eb7b1288", null ],
    [ "get_cube_kd", "BoundingBoxD_8h.html#aecec6f9c6ca668315e6693773ac1c15f", null ],
    [ "get_edges", "BoundingBoxD_8h.html#a17aeb2742e60928cf687ef786530d44c", null ],
    [ "get_interiors_intersect", "BoundingBoxD_8h.html#ab00c98290b98833acf41b7cdfaa1a701", null ],
    [ "get_intersection", "BoundingBoxD_8h.html#a7d107e54c2f6c82ac6af484a62dba718", null ],
    [ "get_maximum_length", "BoundingBoxD_8h.html#a06143c1eada26a19c52b0727f8ab2028", null ],
    [ "get_union", "BoundingBoxD_8h.html#a5884c6b32a247dd314db4c33b92508b8", null ],
    [ "get_unit_bounding_box_d", "BoundingBoxD_8h.html#aefe76b06844e6f12a5c08da8673517b4", null ],
    [ "get_unit_bounding_box_kd", "BoundingBoxD_8h.html#aa88ff22c3c9a9a857314e714d69dea62", null ],
    [ "get_vertices", "BoundingBoxD_8h.html#a8d62bc96f3a84795ae43665423fe9414", null ],
    [ "get_volume", "BoundingBoxD_8h.html#a94f280e1b578da3b5875fb157cfc7c68", null ]
];